import { ParserSyntaxError } from '../../shared';
export type FindModifier = {
    method: 'skip' | 'filter' | 'min' | 'max' | 'returnKey' | 'showRecordId' | 'limit' | 'hint';
    parameters: unknown;
} | {
    method: 'sort';
    parameters?: unknown;
    options?: unknown;
};
interface ExplainParameters {
    parameters?: unknown;
}
export interface FindCommand {
    method: 'find';
    collectionName: string;
    parameters?: unknown;
    options?: unknown;
    explain?: ExplainParameters;
    modifiers: FindModifier[];
}
export interface FindOneCommand {
    method: 'findOne';
    collectionName: string;
    parameters?: unknown;
    options?: unknown;
}
export interface FindOneAndDeleteCommand {
    method: 'findOneAndDelete';
    collectionName: string;
    parameters: unknown;
    options?: unknown;
}
export interface FindOneAndReplaceCommand {
    method: 'findOneAndReplace';
    collectionName: string;
    parameters: unknown;
    replacement: unknown;
    options?: unknown;
}
export interface FindOneAndUpdateCommand {
    method: 'findOneAndUpdate';
    collectionName: string;
    parameters: unknown;
    newValues: unknown;
    options?: unknown;
}
export interface InsertOneCommand {
    method: 'insertOne';
    collectionName: string;
    document: unknown;
    options: unknown;
}
export interface InsertManyCommand {
    method: 'insertMany';
    collectionName: string;
    documents: unknown;
    options: unknown;
}
export interface BulkWriteCommand {
    method: 'bulkWrite';
    collectionName: string;
    operations: unknown;
    options?: unknown;
}
export interface UpdateOneCommand {
    method: 'updateOne';
    collectionName: string;
    filter: unknown;
    updateParameters: unknown;
    options?: unknown;
}
export interface UpdateManyCommand {
    method: 'updateMany';
    collectionName: string;
    filter: unknown;
    updateParameters: unknown;
    options?: unknown;
}
export interface ReplaceOneCommand {
    method: 'replaceOne';
    collectionName: string;
    filter: unknown;
    replacement: unknown;
    options?: unknown;
}
export interface DeleteOneCommand {
    method: 'deleteOne';
    collectionName: string;
    filter?: unknown;
    options?: unknown;
}
export interface DeleteManyCommand {
    method: 'deleteMany';
    collectionName: string;
    filter?: unknown;
    options?: unknown;
}
export interface RenameCommand {
    method: 'rename';
    collectionName: string;
    newName: unknown;
    options?: unknown;
}
export interface DropCommand {
    method: 'drop';
    collectionName: string;
    options?: unknown;
}
export interface IsCappedCommand {
    method: 'isCapped';
    collectionName: string;
    options?: unknown;
}
export interface CreateIndexCommand {
    method: 'createIndex';
    collectionName: string;
    indexSpec: unknown;
    options?: unknown;
}
export interface CreateIndexesCommand {
    method: 'createIndexes';
    collectionName: string;
    indexSpecs: unknown;
    options?: unknown;
}
export interface DropIndexCommand {
    method: 'dropIndex';
    collectionName: string;
    index: unknown;
    options?: unknown;
}
export interface DropIndexesCommand {
    method: 'dropIndexes';
    collectionName: string;
    options?: unknown;
}
export interface ListIndexesCommand {
    method: 'listIndexes';
    collectionName: string;
    options?: unknown;
}
export interface IndexesCommand {
    method: 'indexes';
    collectionName: string;
    options?: unknown;
}
export interface IndexExistsCommand {
    method: 'indexExists';
    collectionName: string;
    indexes: unknown;
    options?: unknown;
}
export interface IndexInformationCommand {
    method: 'indexInformation';
    collectionName: string;
    options?: unknown;
}
export interface EstimatedDocumentCountCommand {
    method: 'estimatedDocumentCount';
    collectionName: string;
    options?: unknown;
}
export interface CountDocumentsCommand {
    method: 'countDocuments';
    collectionName: string;
    filter?: unknown;
    options?: unknown;
}
export interface DistinctCommand {
    method: 'distinct';
    collectionName: string;
    key: unknown;
    filter?: unknown;
    options?: unknown;
}
export interface AggregateCommand {
    method: 'aggregate';
    collectionName: string;
    pipeline?: unknown;
    options?: unknown;
    explain?: ExplainParameters;
}
export type Command = FindCommand | FindOneCommand | FindOneAndDeleteCommand | FindOneAndReplaceCommand | FindOneAndUpdateCommand | InsertOneCommand | InsertManyCommand | BulkWriteCommand | UpdateOneCommand | UpdateManyCommand | ReplaceOneCommand | DeleteOneCommand | DeleteManyCommand | RenameCommand | DropCommand | IsCappedCommand | CreateIndexCommand | CreateIndexesCommand | DropIndexCommand | DropIndexesCommand | ListIndexesCommand | IndexesCommand | IndexExistsCommand | IndexInformationCommand | EstimatedDocumentCountCommand | CountDocumentsCommand | DistinctCommand | AggregateCommand;
export interface ParsingError {
    type: 'parsingError';
    message: string;
}
export interface UnexpectedError {
    type: 'unexpectedError';
    message: unknown;
}
export type ExtractMongoCommandsFromQueryResult = {
    commands: Command[];
} | {
    parseSyntaxErrors: ParserSyntaxError[];
} | {
    parseCommandsError: ParsingError | UnexpectedError;
};
export declare function extractMongoCommandsFromQuery(query: string): ExtractMongoCommandsFromQueryResult;
export {};
